@@ -11,21 +11,13 @@ use Wikibase::Datatype::Print::Lexeme;
 use Wikibase::Datatype::Print::Mediainfo;
 use Wikibase::Datatype::Print::Property;
 
-our $VERSION = 0.16;
-
 Readonly::Array our @EXPORT_OK => qw(print);
 
+our $VERSION = 0.17;
+
 sub print {
 	my ($obj, $opts_hr) = @_;
 
-	if (! defined $opts_hr) {
-		$opts_hr = {};
-	}
-
-	if (! exists $opts_hr->{'lang'}) {
-		$opts_hr->{'lang'} = 'en';
-	}
-
 	my @ret;
 	if ($obj->isa('Wikibase::Datatype::Item')) {
 		@ret = Wikibase::Datatype::Print::Item::print($obj, $opts_hr);
@@ -222,12 +214,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2020-2023 Michal Josef Špaček
+© 2020-2024 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.16
+0.17
 
 =cut
