@@ -7,14 +7,17 @@ use warnings;
 use Error::Pure qw(err);
 use Readonly;
 use Wikibase::Datatype::Print::Snak;
+use Wikibase::Datatype::Print::Utils qw(defaults);
 
 Readonly::Array our @EXPORT_OK => qw(print);
 
-our $VERSION = 0.16;
+our $VERSION = 0.17;
 
 sub print {
 	my ($obj, $opts_hr) = @_;
 
+	$opts_hr = defaults($obj, $opts_hr);
+
 	if (! $obj->isa('Wikibase::Datatype::Reference')) {
 		err "Object isn't 'Wikibase::Datatype::Reference'.";
 	}
@@ -63,6 +66,8 @@ Returns list of lines in array context.
 =head1 ERRORS
 
  print():
+         From Wikibase::Datatype::Print::Utils::defaults():
+                 Defined text keys are bad.
          Object isn't 'Wikibase::Datatype::Reference'.
 
 =head1 EXAMPLE1
@@ -187,13 +192,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2020-2023 Michal Josef Špaček
+© 2020-2024 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.16
+0.17
 
 =cut
-
