@@ -7,23 +7,25 @@ use warnings;
 use Error::Pure qw(err);
 use Readonly;
 use Wikibase::Datatype::Print::Statement;
-use Wikibase::Datatype::Print::Utils qw(print_glosses print_statements);
+use Wikibase::Datatype::Print::Utils qw(defaults print_glosses print_statements);
 use Wikibase::Datatype::Print::Value::Monolingual;
 
 Readonly::Array our @EXPORT_OK => qw(print);
 
-our $VERSION = 0.16;
+our $VERSION = 0.17;
 
 sub print {
 	my ($obj, $opts_hr) = @_;
 
+	$opts_hr = defaults($obj, $opts_hr);
+
 	if (! $obj->isa('Wikibase::Datatype::Sense')) {
 		err "Object isn't 'Wikibase::Datatype::Sense'.";
 	}
 
 	# Id.
 	my @ret = (
-		'Id: '.$obj->id,
+		$opts_hr->{'texts'}->{'id'}.': '.$obj->id,
 	);
 
 	# Glosses.
@@ -72,6 +74,8 @@ Returns list of lines in array context.
 =head1 ERRORS
 
  print():
+         From Wikibase::Datatype::Print::Utils::defaults():
+                 Defined text keys are bad.
          Object isn't 'Wikibase::Datatype::Sense'.
 
 =head1 EXAMPLE
@@ -177,13 +181,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2020-2023 Michal Josef Špaček
+© 2020-2024 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.16
+0.17
 
 =cut
-
